@@ -7,11 +7,11 @@
  */
 #include <collectionindexingjob.h>
 
-#include <AkonadiCore/Collection>
-#include <AkonadiCore/CollectionFetchJob>
-#include <AkonadiCore/ServerManager>
-#include <AkonadiCore/qtest_akonadi.h>
+#include <Akonadi/Collection>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/ServerManager>
 #include <QTest>
+#include <akonadi/qtest_akonadi.h>
 
 class TestIndex : public Index
 {
