@@ -15,7 +15,7 @@
 #include <Akonadi/SearchQuery>
 
 #include "akonadiplugin_indexer_debug.h"
-#include <Akonadi/KMime/MessageFlags>
+#include <Akonadi/MessageFlags>
 #include <KContacts/Addressee>
 #include <KContacts/ContactGroup>
 
@@ -61,9 +61,9 @@ static Term getTerm(const Akonadi::SearchTerm &term, const QString &property)
 
 Term recursiveEmailTermMapping(const Akonadi::SearchTerm &term)
 {
-    if (!term.subTerms().isEmpty()) {
+    const auto subTermsResult = term.subTerms();
+    if (!subTermsResult.isEmpty()) {
         Term t(mapRelation(term.relation()));
-        const auto subTermsResult = term.subTerms();
         for (const Akonadi::SearchTerm &subterm : subTermsResult) {
             const Term newTerm = recursiveEmailTermMapping(subterm);
             if (newTerm.isValid()) {
@@ -183,14 +183,15 @@ Term recursiveEmailTermMapping(const Akonadi::SearchTerm &term)
             }
         }
     }
-    return Term();
+    return {};
 }
 
 Term recursiveCalendarTermMapping(const Akonadi::SearchTerm &term)
 {
-    if (!term.subTerms().isEmpty()) {
+    const auto subTerms{term.subTerms()};
+    if (!subTerms.isEmpty()) {
         Term t(mapRelation(term.relation()));
-        for (const Akonadi::SearchTerm &subterm : term.subTerms()) {
+        for (const Akonadi::SearchTerm &subterm : subTerms) {
             const Term newTerm = recursiveCalendarTermMapping(subterm);
             if (newTerm.isValid()) {
                 t.addSubTerm(newTerm);
@@ -218,14 +219,15 @@ Term recursiveCalendarTermMapping(const Akonadi::SearchTerm &term)
             }
         }
     }
-    return Term();
+    return {};
 }
 
 Term recursiveNoteTermMapping(const Akonadi::SearchTerm &term)
 {
-    if (!term.subTerms().isEmpty()) {
+    const auto subTerms{term.subTerms()};
+    if (!subTerms.isEmpty()) {
         Term t(mapRelation(term.relation()));
-        for (const Akonadi::SearchTerm &subterm : term.subTerms()) {
+        for (const Akonadi::SearchTerm &subterm : subTerms) {
             const Term newTerm = recursiveNoteTermMapping(subterm);
             if (newTerm.isValid()) {
                 t.addSubTerm(newTerm);
@@ -246,14 +248,15 @@ Term recursiveNoteTermMapping(const Akonadi::SearchTerm &term)
             }
         }
     }
-    return Term();
+    return {};
 }
 
 Term recursiveContactTermMapping(const Akonadi::SearchTerm &term)
 {
-    if (!term.subTerms().isEmpty()) {
+    const auto subTerms{term.subTerms()};
+    if (!subTerms.isEmpty()) {
         Term t(mapRelation(term.relation()));
-        for (const Akonadi::SearchTerm &subterm : term.subTerms()) {
+        for (const Akonadi::SearchTerm &subterm : subTerms) {
             const Term newTerm = recursiveContactTermMapping(subterm);
             if (newTerm.isValid()) {
                 t.addSubTerm(newTerm);
@@ -279,7 +282,7 @@ Term recursiveContactTermMapping(const Akonadi::SearchTerm &term)
             }
         }
     }
-    return Term();
+    return {};
 }
 
 QSet<qint64> SearchPlugin::search(const QString &akonadiQuery, const QVector<qint64> &collections, const QStringList &mimeTypes)
@@ -344,7 +347,7 @@ QSet<qint64> SearchPlugin::search(const QString &akonadiQuery, const QVector<qin
     } else {
         if (t.subTerms().isEmpty()) {
             qCWarning(AKONADIPLUGIN_INDEXER_LOG) << "no terms added";
-            return QSet<qint64>();
+            return {};
         }
 
         query.setTerm(t);
