@@ -1,15 +1,14 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AKONADISEARCHDEBUGDIALOG_H
-#define AKONADISEARCHDEBUGDIALOG_H
+#pragma once
 
 #include "akonadisearchdebugsearchpathcombobox.h"
 #include "search_debug_export.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <QDialog>
 
 namespace Akonadi
@@ -26,7 +25,7 @@ class AKONADI_SEARCH_DEBUG_EXPORT AkonadiSearchDebugDialog : public QDialog
     Q_OBJECT
 public:
     explicit AkonadiSearchDebugDialog(QWidget *parent = nullptr);
-    ~AkonadiSearchDebugDialog();
+    ~AkonadiSearchDebugDialog() override;
 
     void setAkonadiId(Akonadi::Item::Id akonadiId);
     void setSearchType(AkonadiSearchDebugSearchPathComboBox::SearchType type);
@@ -38,9 +37,8 @@ private:
     void readConfig();
     void writeConfig();
     void saveTextAs(const QString &text, const QString &filter);
+    Q_REQUIRED_RESULT bool saveToFile(const QString &filename, const QString &text);
     AkonadiSearchDebugDialogPrivate *const d;
-    bool saveToFile(const QString &filename, const QString &text);
 };
 }
 }
-#endif // AKONADISEARCHDEBUGDIALOG_H
