@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,18 +16,16 @@ AkonadiSearchDebugSearchPathComboBox::AkonadiSearchDebugSearchPathComboBox(QWidg
     initialize();
 }
 
-AkonadiSearchDebugSearchPathComboBox::~AkonadiSearchDebugSearchPathComboBox()
-{
-}
+AkonadiSearchDebugSearchPathComboBox::~AkonadiSearchDebugSearchPathComboBox() = default;
 
-QString AkonadiSearchDebugSearchPathComboBox::searchPath()
+QString AkonadiSearchDebugSearchPathComboBox::searchPath() const
 {
     const int currentPathIndex = currentIndex();
     if (currentPathIndex > -1) {
         const QString value = pathFromEnum(static_cast<Akonadi::Search::AkonadiSearchDebugSearchPathComboBox::SearchType>(itemData(currentPathIndex).toInt()));
         return value;
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -40,7 +38,7 @@ void AkonadiSearchDebugSearchPathComboBox::initialize()
     addItem(QStringLiteral("Calendars"), Calendars);
 }
 
-QString AkonadiSearchDebugSearchPathComboBox::pathFromEnum(SearchType type)
+QString AkonadiSearchDebugSearchPathComboBox::pathFromEnum(SearchType type) const
 {
     switch (type) {
     case Contacts:
@@ -54,7 +52,7 @@ QString AkonadiSearchDebugSearchPathComboBox::pathFromEnum(SearchType type)
     case Calendars:
         return defaultLocations(QStringLiteral("calendars"));
     }
-    return QString();
+    return {};
 }
 
 void AkonadiSearchDebugSearchPathComboBox::setSearchType(AkonadiSearchDebugSearchPathComboBox::SearchType type)
@@ -65,7 +63,7 @@ void AkonadiSearchDebugSearchPathComboBox::setSearchType(AkonadiSearchDebugSearc
     }
 }
 
-QString AkonadiSearchDebugSearchPathComboBox::defaultLocations(const QString &dbName)
+const QString AkonadiSearchDebugSearchPathComboBox::defaultLocations(const QString &dbName) const
 {
     // First look into the old location from Baloo times in ~/.local/share/baloo,
     // because we don't migrate the database files automatically.
