@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -31,7 +31,7 @@ public:
     void setSearchType(AkonadiSearchDebugSearchPathComboBox::SearchType type);
     void doSearch();
 
-    QString plainText() const;
+    Q_REQUIRED_RESULT QString plainText() const;
 
 private Q_SLOTS:
     void slotSearchLineTextChanged(const QString &text);
@@ -40,10 +40,10 @@ private Q_SLOTS:
     void slotError(const QString &errorStr);
 
 private:
-    QPlainTextEdit *mPlainTextEditor = nullptr;
-    AkonadiSearchDebugSearchPathComboBox *mSearchPathComboBox = nullptr;
-    KLineEdit *mLineEdit = nullptr;
-    QPushButton *mSearchButton = nullptr;
+    QPlainTextEdit *const mPlainTextEditor;
+    AkonadiSearchDebugSearchPathComboBox *const mSearchPathComboBox;
+    KLineEdit *const mLineEdit;
+    QPushButton *const mSearchButton;
 };
 }
 }
