@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ AkonadiSearchDebugWidgetTest::AkonadiSearchDebugWidgetTest(QObject *parent)
 {
 }
 
-AkonadiSearchDebugWidgetTest::~AkonadiSearchDebugWidgetTest()
-{
-}
+AkonadiSearchDebugWidgetTest::~AkonadiSearchDebugWidgetTest() = default;
 
 void AkonadiSearchDebugWidgetTest::shouldHaveDefaultValue()
 {
