@@ -38,14 +38,17 @@ public:
     void matchUID(const QString &uid);
     void match(const QString &str);
 
-    enum MatchCriteria { ExactMatch, StartsWithMatch };
+    enum MatchCriteria {
+        ExactMatch,
+        StartsWithMatch,
+    };
 
     void setMatchCriteria(MatchCriteria m);
-    MatchCriteria matchCriteria() const;
+    Q_REQUIRED_RESULT MatchCriteria matchCriteria() const;
 
     ResultIterator exec() override;
 
-    int limit() const;
+    Q_REQUIRED_RESULT int limit() const;
     void setLimit(int limit);
 
 private:
@@ -54,4 +57,3 @@ private:
 }
 }
 }
-
